@@ -388,11 +388,18 @@ def accounts(self):
 
     self.add('AUTH', "accounts")
     self.add('VOID', "accounts", "access")
+    self.add('AUTH', 'accounts', 'access/certificates')
     self.add('AUTH', "accounts", "access/groups")
     self.add('AUTH', "accounts", "access/identity_providers")
     self.add('AUTH', "accounts", "access/organizations")
     self.add('AUTH', "accounts", "access/organizations/revoke_user")
     self.add('AUTH', "accounts", "access/service_tokens")
+    self.add('VOID', "accounts", "access/logs")
+    self.add('AUTH', 'accounts', 'access/logs/access-requests')
+    self.add('AUTH', 'accounts', 'access/apps')
+    self.add('AUTH', 'accounts', 'access/apps', 'ca')
+    self.add('AUTH', 'accounts', 'access/apps', 'policies')
+    self.add('AUTH', 'accounts', 'access/apps', 'revoke-tokens')
     self.add('VOID', "accounts", "billing")
     self.add('AUTH', "accounts", "billing/profile")
     self.add('AUTH', "accounts", "custom_pages")
@@ -402,6 +409,10 @@ def accounts(self):
     self.add('VOID', "accounts", "registrar")
     self.add('AUTH', "accounts", "registrar/domains")
     self.add('AUTH', "accounts", "roles")
+    self.add('VOID', 'accounts', 'rules')
+    self.add('AUTH', 'accounts', 'rules/lists')
+    self.add('AUTH', 'accounts', 'rules/lists', 'items')
+    self.add('AUTH', 'accounts', 'rules/lists/bulk-operations')
     self.add('VOID', "accounts", "storage")
     self.add('AUTH', "accounts", "storage/analytics")
     self.add('AUTH', "accounts", "storage/analytics/stored")
